@@ -23,7 +23,7 @@ try:
 except:
     print("Unable to import Ipyvolume")
 
-__VERSION__ = "0.0.14"
+__VERSION__ = "0.0.15"
 
 """
     A module to analyze cytosim simulations
@@ -236,11 +236,10 @@ class Simulation(list):
             #if self.figure is None:
             #    self.figure = ipv.figure()
 
-            if len(args==0):
+            if len(args) == 0:
                 ipv.show()
                 self.shown=True
-
-            elif len(args==1):
+            else:
                 number=args[0]
                 if len(args)>1:
                     args = args[1:]
